==> piwigo-11.5.0.zip: piwigo/language/pt_PT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalação';
$lang['Basic configuration'] = 'Configuração Básica';
$lang['Default gallery language'] = 'Idioma padrão da galeria';
$lang['Database configuration'] = 'Configuração da base de dados';
$lang['Admin configuration'] = 'Configuração da administração';
$lang['Start Install'] = 'Iniciar a instalação';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será mostrado aos visitantes. É necessário para a administração do sitio';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A ligação ao servidor foi bem sucedida, mas foi impossível ligar à base de dados';
$lang['Can\'t connect to server'] = 'Não foi possível ligar ao servidor';
$lang['Host'] = 'Servidor MySQL';
$lang['User'] = 'Utilizador';
$lang['user login given by your host provider'] = 'Login de utilizador fornecido pelo seu fornecedor de alojamento';
$lang['user password given by your host provider'] = 'Palavra-passe fornecida pelo seu fornecedor de alojamento';
$lang['Database name'] = 'Nome da base de dados';
$lang['also given by your host provider'] = 'Também fornecido pelo seu fornecedor de alojamento';
$lang['Database table prefix'] = 'Prefixo da tabela da base de dados';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Os nomes das tabelas da base de dados terão este prefixo (isto possibilita uma melhor gestão das tabelas)';
$lang['enter a login for webmaster'] = 'Introduza um nome para o webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'O nome do webmaster não pode conter os caracteres \' ou "';
$lang['please enter your password again'] = 'Por favor, escreva a sua senha novamente';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantenha-a bem guardada, é ela que lhe permite aceder ao painel administrativo';
$lang['Password [confirm]'] = 'Palavra-passe [confirmação]';
$lang['verification'] = 'Verificar Senha inserida';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisa de ajuda? Faça a sua pergunta no <a href="%s">Fórum Piwigo</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderão entrar em contacto com o administrador da galeria através deste email';
$lang['PHP 5 is required'] = 'PHP 5.2 é necessário';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que o seu provedor de hospedagem usa actualmente PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tentar mudar a sua configuração para PHP 5.2 através da criação ou modificação de um arquivo .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note que você pode alterar sua configuração por conta própria e reiniciar o Piwigo depois disso.';
$lang['Try to configure PHP 5'] = 'Tentar configurar PHP 5.2';
$lang['Sorry!'] = 'Lamentamos!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo não pôde configurar o PHP 5.2';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Você deve entrar em contacto com o suporte do seu provedor e saber como pode mudar para PHP 5.";
$lang['Hope to see you back soon.'] = 'Desejamos volte em breve.';
$lang['Congratulations, Piwigo installation is completed'] = 'Parabéns, a sua instalação Piwigo está completa';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Uma solução alternativa será copiar o texto na caixa supra e colá-lo no ficheiro "local/config/database.inc.php" (Atenção : database.inc.php apenas deverá conter o que está na área de texto, não insira nenhuma linha nova ou espaço em branco)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'A criação do ficheiro de configuração local/config/database.inc.php falhou.';
$lang['Download the config file'] = 'Guardar ficheiro de configuração';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Pode guardar o ficheiro de configuração no seu computador e de seguida enviá-lo para a pasta /local/config da sua instalação.';
$lang['Just another Piwigo gallery'] = 'Apenas mais uma galeria Piwigo';
$lang['Welcome to my photo gallery'] = 'Bem-vindo à minha galeria de fotos';
$lang['Welcome to your new installation of Piwigo!'] = 'Bem-vindo à sua nova instalação do Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Não hesite em visitar nossos foruns para qualquer ajuda: %s';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Você deve entrar em contacto com o suporte do seu fornecedor de alojamento e saber como pode mudar para PHP 5.2';
$lang['Password ']['confirm'] = 'Senha [confirme]';
$lang['localhost or other, supplied by your host provider'] = 'hospedeiro local ou outro, fornecido pelo seu alojador';

==> piwigo-16.0.0.zip: piwigo/language/pt_PT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Instalação';
$lang['Basic configuration'] = 'Configuração Básica';
$lang['Default gallery language'] = 'Idioma padrão da galeria';
$lang['Database configuration'] = 'Configuração da base de dados';
$lang['Admin configuration'] = 'Configuração da administração';
$lang['Start Install'] = 'Iniciar a instalação';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Será mostrado aos visitantes. É necessário para a administração do sitio';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'A ligação ao servidor foi bem sucedida, mas foi impossível ligar à base de dados';
$lang['Can\'t connect to server'] = 'Não foi possível ligar ao servidor';
$lang['Host'] = 'Servidor MySQL';
$lang['User'] = 'Utilizador';
$lang['user login given by your host provider'] = 'Login de utilizador fornecido pelo seu fornecedor de alojamento';
$lang['user password given by your host provider'] = 'Palavra-passe fornecida pelo seu fornecedor de alojamento';
$lang['Database name'] = 'Nome da base de dados';
$lang['also given by your host provider'] = 'Também fornecido pelo seu fornecedor de alojamento';
$lang['Database table prefix'] = 'Prefixo da tabela da base de dados';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Os nomes das tabelas da base de dados terão este prefixo (isto possibilita uma melhor gestão das tabelas)';
$lang['enter a login for webmaster'] = 'Introduza um nome para o webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'O nome do webmaster não pode conter os caracteres \' ou "';
$lang['please enter your password again'] = 'Por favor, escreva a sua senha novamente';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Mantenha-a bem guardada, é ela que lhe permite aceder ao painel administrativo';
$lang['Password [confirm]'] = 'Palavra-passe [confirmação]';
$lang['verification'] = 'Verificar Senha inserida';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Precisa de ajuda? Faça a sua pergunta no <a href="%s">Fórum Piwigo</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Os visitantes poderão entrar em contacto com o administrador da galeria através deste email';
$lang['PHP 5 is required'] = 'PHP 5.2 é necessário';
$lang['It appears your webhost is currently running PHP %s.'] = 'Parece que o seu provedor de hospedagem usa actualmente PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo pode tentar mudar a sua configuração para PHP 5.2 através da criação ou modificação de um arquivo .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Note que você pode alterar sua configuração por conta própria e reiniciar o Piwigo depois disso.';
$lang['Try to configure PHP 5'] = 'Tentar configurar PHP 5.2';
$lang['Sorry!'] = 'Lamentamos!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo não pôde configurar o PHP 5.2';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Você deve entrar em contacto com o suporte do seu provedor e saber como pode mudar para PHP 5.";
$lang['Hope to see you back soon.'] = 'Desejamos volte em breve.';
$lang['Congratulations, Piwigo installation is completed'] = 'Parabéns, a sua instalação Piwigo está completa';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Uma solução alternativa será copiar o texto na caixa supra e colá-lo no ficheiro "local/config/database.inc.php" (Atenção : database.inc.php apenas deverá conter o que está na área de texto, não insira nenhuma linha nova ou espaço em branco)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'A criação do ficheiro de configuração local/config/database.inc.php falhou.';
$lang['Download the config file'] = 'Guardar ficheiro de configuração';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Pode guardar o ficheiro de configuração no seu computador e de seguida enviá-lo para a pasta /local/config da sua instalação.';
$lang['Just another Piwigo gallery'] = 'Apenas mais uma galeria Piwigo';
$lang['Welcome to my photo gallery'] = 'Bem-vindo à minha galeria de fotos';
$lang['Welcome to your new installation of Piwigo!'] = 'Bem-vindo à sua nova instalação do Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Não hesite em visitar nossos foruns para qualquer ajuda: %s';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Você deve entrar em contacto com o suporte do seu fornecedor de alojamento e saber como pode mudar para PHP 5.2';
$lang['Password ']['confirm'] = 'Senha [confirme]';
$lang['localhost or other, supplied by your host provider'] = 'hospedeiro local ou outro, fornecido pelo seu alojador';
$lang['PHP version %s required (you are running on PHP %s)'] = 'Versão do PHP %s necessária (você está executando em PHP %s)';
